const Wait = require('./wait');

class AssertElement {
  constructor(page, elementSelector) {
    this.page = page;
    this.elementSelector = elementSelector;
  }

  assertElementVisible() {
    const wait = new Wait(this.page, this.elementSelector);
    wait.waitElementPresent();
    return this.page.assert.visible(this.elementSelector);
  }

  assertElementPresent() {
    return this.page.assert.elementPresent(this.elementSelector);
  }

  assertElementNotPresent() {
    return this.page.assert.elementNotPresent(this.elementSelector);
  }

  assertElementsContainText(client, expectedText) {
    let selector;
    if (this.elementSelector.startsWith('//')) {
      selector = 'xpath';
    } else {
      selector = 'css selector';
    }
    client.elements(selector, this.elementSelector, (element) => {
      Object.keys(element.value).forEach((key) => {
        client.elementIdAttribute(key.ELEMENT, 'innerText', (result) => {
          this.page.assert.ok(result.value.indexOf(expectedText) !== -1, `Testing if element <${this.elementSelector}> contains text that matches "${expectedText}"`);
        });
      });
    });
  }
}

module.exports = AssertElement;
