class Label {
  constructor(page, elementSelector, expectedText) {
    this.page = page;
    this.elementSelector = elementSelector;
    this.expectedText = expectedText;
    this.totalFound = false;
  }

  isLabel() {
    return this.page.expect.element(this.elementSelector).to.be.a('label');
  }

  isNotLabel() {
    return this.page.expect.element(this.elementSelector).to.not.be.a('label');
  }

  isParagraph() {
    return this.page.expect.element(this.elementSelector).to.be.a('p');
  }

  isSpan() {
    return this.page.expect.element(this.elementSelector).to.be.a('span');
  }

  clickLabel() {
    this.isLabel();
    this.page.click(this.elementSelector);
  }

  expectEqualText() {
    this.isLabel();
    return this.page.expect.element(this.elementSelector).text.to.equal(this.expectedText);
  }

  expectNotEqualText() {
    this.isLabel();
    return this.page.expect.element(this.elementSelector).text.to.not.equal(this.expectedText);
  }

  expectContainsText() {
    return this.page.expect.element(this.elementSelector).text.to.contains(this.expectedText);
  }

  expectLabelContainsText() {
    this.isLabel();
    return this.expectContainsText();
  }

  expectParagraphContainsText() {
    this.isParagraph();
    return this.expectContainsText();
  }

  expectSpanContainsText() {
    this.isSpan();
    return this.expectContainsText();
  }

  assertContainsText() {
    return this.page.assert.containsText(this.elementSelector, this.expectedText);
  }

  assertLabelContainsText() {
    this.isLabel();
    return this.assertContainsText();
  }

  assertParagraphContainsText() {
    this.isParagraph();
    return this.assertContainsText();
  }

  assertSpanContainsText() {
    this.isSpan();
    return this.assertContainsText();
  }

  searchTextByLabelElements() {
    this.page.elements('css selector', this.elementSelector, (result) => {
      Object.keys(result.value).forEach((key) => {
        this.page.elementIdText(result.value[key].ELEMENT, (res) => {
          if (res.value.indexOf(this.expectedText) > -1) {
            this.totalFound = true;
          }
        });
      });
    });
    return this.page.perform(() => {
      if (this.totalFound === true) {
        this.page.assert.visible(this.elementSelector);
      } else {
        throw new Error(`searchTextByLabelElements - Element ${this.elementSelector} with text: ${this.expectedText} is NOT FOUND`);
      }
    });
  }
}

class LabelOptional {
  constructor(page, client, elementSelector) {
    this.page = page;
    this.client = client;
    this.elementSelector = elementSelector;
  }

  isLabel() {
    return this.page.expect.element(this.elementSelector).to.be.a('label');
  }

  clickLabelOptional() {
    this.client.element('css selector', this.elementSelector, (result) => {
      if (result.status !== -1) {
        this.isLabel();
        this.page.click(this.elementSelector);
      }
    });
  }
}

module.exports = { Label, LabelOptional };
